flex_seek_bar library

Classes

CircularSeekBar
A circular arc seek bar.
FlexSeekBar
A fully customisable linear seek bar that supports both single and range slider modes.
SeekBarController
A controller that lets you read and programmatically update seek bar values.
SeekBarStyle
Controls every visual aspect of FlexSeekBar.

Enums

SeekBarType
Defines the type of seek bar to render.